@@ -73,6 +73,7 @@
 }
 
 
+
 ##' @aliases all.equal  all.equal,hyperSpec,hyperSpec-method
 ##' @rdname Comparison
 ##' @param target,current two \code{hyperSpec} objects that are tested for
@@ -83,13 +84,14 @@
 ##'   of the columns (determined by the names) differs, should they be regarded
 ##'   as different?
 ##' @param check.label Should the slot \code{label} be checked? \cr If the
-##'   labels differ only in the order of their entries, they are conidered
+##'   labels differ only in the order of their entries, they are considered
 ##'   equal.
 ##' @param check.attributes,check.names see \code{\link[base]{all.equal}}
 ##' @param tolerance,wl.tolerance tolerances for checking wavelengths and data, respectively
-##' @return \code{all.equal} returns either \code{TRUE}, or a character vector describing the
+##' @returns  \code{all.equal} returns either \code{TRUE}, or a character vector describing the
 ##' differences. In conditions, the result must therefore be tested with
 ##' \code{\link[base]{isTRUE}}.
 ##' @seealso \code{\link[base]{all.equal}} and \code{\link[base]{isTRUE}}
+##' @docType methods
 ##' @export
-setMethod ("all.equal", signature (target = "hyperSpec", current = "hyperSpec"), .all.equal)
+setMethod ("all.equal", signature = signature (target = "hyperSpec", current = "hyperSpec"), .all.equal)
