@@ -30,5 +30,4 @@
 ##' @include paracetamol.R
 ##' @include barbiturates.R
 ##' @include unittest.R
-##' @keywords package
-NULL
+"_PACKAGE"
