@@ -117,8 +117,8 @@ split.line <- function (x, separator, trim.blank = TRUE) {
   if (is.null (header$interleave))
     header$interleave <- "bsq"
 
-  if (any (is.null (header [c ("samples", "lines", "bands", "data type")]) ||
-           is.na   (header [c ("samples", "lines", "bands", "data type")]) ))
+  if (     is.null (header [c ("samples", "lines", "bands", "data type")]) ||
+      any (is.na   (header [c ("samples", "lines", "bands", "data type")]) ))
     stop("Error in ENVI header (required entry missing or incorrect)\n header: ",
          paste (names (header), " = ", header, collapse = ", "))
 
