@@ -1,3 +1,15 @@
+.split <- function (x, f, drop = TRUE){
+	validObject (x)
+	
+	hyperlist <- split (seq (x, index = TRUE), f, drop)
+	
+	for (i in seq_along (hyperlist)){
+		hyperlist [[i]] <- x [hyperlist [[i]], ]
+	}
+	
+	hyperlist
+}
+
 ##' Split a hyperSpec object according to groups
 ##' \code{split} divides the \code{hyperSpec} object into a list of
 ##' \code{hyperSpec} objects according to the groups given by \code{f}.
@@ -14,7 +26,6 @@
 ##'   into a factor by \code{as.factor})
 ##' @param drop if \code{TRUE}, levels of\code{f} that do not occur are
 ##'   dropped.
-##' @param short,user,date handed to \code{\link{logentry}}
 ##' @return A list of \code{hyperSpec} objects.
 ##' @author C. Beleites
 ##' @seealso \code{\link[base]{split}}
@@ -35,20 +46,4 @@
 ##' 
 
 
-setMethod ("split", signature = signature (x = "hyperSpec"),
-           function (x, f, drop = TRUE, #...,
-                     short = NULL, user = NULL, date = NULL){
-  validObject (x)
-
-  hyperlist <- split (seq (x, index = TRUE), f, drop)
-
-  log <-  .logentry (x, short = short, long = list (f = f, drop = drop),
-                    user = user, date = date)@log
-
-  for (i in seq_along (hyperlist)){
-    hyperlist [[i]] <- x [hyperlist [[i]], ]
-    hyperlist [[i]]@log <- log
-  }
-
-  hyperlist
-})
+setMethod ("split", signature = signature (x = "hyperSpec"), .split)
