@@ -6,7 +6,7 @@
 
 split.string <- function (x, separator, trim.blank = TRUE, remove.empty = TRUE) {
   pos <- gregexpr (separator, x)
-  if (length (pos) == 1 && pos [[1]] == -1)
+  if (length (pos) == 1 && length (pos[[1]]) == 1 && pos [[1]] == -1)
     return (x)
 
   pos <- pos [[1]]
